# -*- coding: utf-8 -*-

""" Module

lpom -- Local Partial Order Model.

LPOM0 and LPOMext are approximations to calculate the
average height, hav, of partially ordered sets (posets).

"""
name = "pyhasse.lpom"

__author__ = """Rainer Bruggemann"""
__email__ = 'rainer.bruggemann@pyhasse.org'
__version__ = '0.2.1'
